/*
 * Copyright (c) Alex Allan <alex X kamaz.org.uk> 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * cddb_query.cpp
 * CDDB query implementation largely uses CDDBQueryImpl
 */
 
#include <vector>

#include "tracks.h"

// Implements:
#include "cddb_query.h"

#include "cddb_query_impl.h"

namespace TagLookup
{
    CDDBQuery::CDDBQuery()
    {
        pimpl = new CDDBQueryImpl();
    }
    
    CDDBQuery::CDDBQuery(const unsigned int length, const OffsetList &offsets)
    {
        pimpl = new CDDBQueryImpl(length, offsets);
    }

    CDDBQuery::CDDBQuery(const std::string &category, const unsigned int disc_id)
    {
        pimpl = new CDDBQueryImpl(category, disc_id);
    }

    CDDBQuery::~CDDBQuery()
    {
        delete pimpl; //can't throw
    }
    
    const Discs & CDDBQuery::getResults()
    {
        return pimpl->getResults();
    }
    
    void CDDBQuery::query()
    {
        pimpl->query();
    }

    void CDDBQuery::setProtocolHTTP(const std::string &hostname, const unsigned int port)
    {
        pimpl->setProtocolHTTP(hostname, port);
    }
    
    void CDDBQuery::setProtocolHTTP(const std::string &hostname, 
        const unsigned int port, 
        const std::string &proxy_hostname, 
        const unsigned int proxy_port, 
        const std::string &proxy_username, 
        const std::string &proxy_password)
    {
        pimpl->setProtocolHTTP(hostname, 
            port, 
            proxy_hostname, 
            proxy_port, 
            proxy_username, 
            proxy_password);
    }
    
    void CDDBQuery::setProtocolCDDBP(const std::string &hostname, const unsigned int port)
    {
        pimpl->setProtocolCDDBP(hostname, port);
    }

    void CDDBQuery::setCache(const Cache &cache)
    {
        pimpl->setCache(cache);
    }
    
}

