/*
 * Copyright (c) Alex Allan <alex X kamaz.org.uk> 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * cddb_query_impl.h
 * Implementation header for CDDBQuery using libcddb.
 */

#ifndef TAGLOOKUP_CDDB_QUERY_IMPL_H
#define TAGLOOKUP_CDDB_QUERY_IMPL_H

#include <vector>
#include <cddb/cddb.h>

#include "cddb_query.h"

namespace TagLookup
{
    class CDDBQueryImpl
    {
    public:
        // Methods
        CDDBQueryImpl();
        CDDBQueryImpl(const unsigned int length, const std::vector<int> &offsets);
        CDDBQueryImpl(const std::string &category, const unsigned int disc_id);
        virtual ~CDDBQueryImpl();

        void query();
        const Discs & getResults();
        
        void setProtocolHTTP(const std::string &hostname, const unsigned int port);

        void setProtocolHTTP(const std::string &hostname, 
            const unsigned int port, 
            const std::string &proxy_hostname, 
            const unsigned int proxy_port, 
            const std::string &proxy_username, 
            const std::string &proxy_password);

        void setProtocolCDDBP(const std::string &hostname, const unsigned int port);

        void setCache(const Cache & cache);
    private:
        unsigned int length_;
        std::vector<int> offsets_;
        std::string category_;
        unsigned int disc_id_;

        Discs results_;
        
        cddb_conn_t *conn_;

        void init();
        Disc createDiscFromCDDBDisc(cddb_disc_t *d);
    }; // struct CDDBQueryImpl
    
}

#endif

