/*
 * Copyright (c) Alex Allan <alex X kamaz.org.uk> 
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * tracks.h
 * A number of classes for defining a track andhow these are grouped into 
 * discs and then lists of discs.
 */
 
#ifndef TAGLOOKUP_TRACKS_H
#define TAGLOOKUP_TRACKS_H

#include <vector>
#include <string>

namespace TagLookup
{
    class Track
    {
    public:
        Track()
            : name_(), artist_(), length_(0), track_no_(0)
        {}

        Track(const std::string &name, const std::string &artist, const unsigned int length, const unsigned int track_no)
            : name_(name), artist_(artist), length_(length), track_no_(track_no)
        {}

        Track(const Track &other)
        {
            // use the default assignment copy
            *this = other;
        }
        
        const std::string & getName() const
        {
            return name_;
        }
        
        const std::string & getArtist() const
        {
            return artist_;
        }
        
        const unsigned int getTrackNo() const
        {
            return track_no_;
        }
        
        const unsigned int getLength() const
        {
            return length_;
        }

    private:
        std::string name_;
        std::string artist_;
        unsigned int length_;
        unsigned int track_no_;

    }; // class Track
    
    typedef std::vector<Track> Tracks;
    
    class Disc
    {
    public:
        Disc()
            : title_(), artist_(), genre_(), year_(0)
        {
        }
        
        Disc(const std::string &title, const std::string &artist, const std::string &genre, const unsigned int year)
            : title_(title), artist_(artist), genre_(genre), year_(year)
        {
        }
        
        Disc(const Disc &other)
        {
            // use the default assignment copy
            *this = other;
        }

        const std::string & getTitle() const
        {
            return title_;
        }
        
        const std::string & getArtist() const
        {
            return artist_;
        }
        
        const std::string & getGenre() const
        {
            return genre_;
        }
        
        const unsigned int getYear() const
        {
            return year_;
        }
        
        const std::vector<Track> & getTracks() const
        {
            return tracks_;
        }
        
        void appendTrack(const Track & new_track);
        
    private:
        std::string title_;
        std::string artist_;
        std::string genre_;
        unsigned int year_;
        
        std::vector<Track> tracks_;
    }; // class Disc
    
    // Discs is implemented as a typedef
    typedef std::vector<Disc> Discs;
}

#endif 


